@@ -1,27 +1,235 @@
-# class and methods for Partial Least Squares regression #
-
+#' Partial Least Squares regression
+#'
+#' @description 
+#' \code{pls} is used to calibrate, validate and use of partial least squares (PLS) 
+#' regression model.
+#' 
+#' @param x
+#' matrix with predictors.
+#' @param y  
+#' matrix with responses.
+#' @param ncomp
+#' maximum number of components to calculate.
+#' @param center   
+#' logical, center or not predictors and response values.
+#' @param scale   
+#' logical, scale (standardize) or not predictors and response values.
+#' @param cv  
+#' number of segments for cross-validation (if cv = 1, full cross-validation will be used).
+#' @param x.test   
+#' matrix with predictors for test set.
+#' @param y.test  
+#' matrix with responses for test set.
+#' @param method   
+#' method for calculating PLS model.
+#' @param alpha   
+#' significance level for calculating statistical limits for residuals.
+#' @param coeffs.ci   
+#' method to calculate p-values and confidence intervals for regression coefficients (so far only 
+#' jack-knifing is availavle: \code{='jk'}).
+#' @param coeffs.alpha   
+#' significance level for calculating confidence intervals for regression coefficients.
+#' @param info   
+#' short text with information about the model.
+#' @param light   
+#' run normal or light (faster) version of PLS without calculationg some performance statistics.
+#' @param ncomp.selcrit  
+#' criterion for selecting optimal number of components (\code{'min'} for 
+#' first local minimum of RMSECV and \code{'wold'} for Wold's rule.)
+#' 
+#' @return 
+#' Returns an object of \code{pls} class with following fields:
+#' \item{ncomp }{number of components included to the model.} 
+#' \item{ncomp.selected }{selected (optimal) number of components.} 
+#' \item{xloadings }{matrix with loading values for x decomposition.} 
+#' \item{yloadings }{matrix with loading values for y decomposition.} 
+#' \item{weights }{matrix with PLS weights.} 
+#' \item{selratio }{array with selectivity ratio values.} 
+#' \item{vipscores }{matrix with VIP scores values.} 
+#' \item{coeffs }{object of class \code{\link{regcoeffs}} with regression coefficients calculated for each component.}   
+#' \item{info }{information about the model, provided by user when build the model.} 
+#' \item{calres }{an object of class \code{\link{plsres}} with PLS results for a calibration data.} 
+#' \item{testres }{an object of class \code{\link{plsres}} with PLS results for a test data, if it was provided.} 
+#' \item{cvres }{an object of class \code{\link{plsres}} with PLS results for cross-validation, if this option was chosen.} 
+#'
+#' @details 
+#' So far only SIMPLS method [1] is available, more coming soon. Implementation works both with one
+#' and multiple response variables.
+#'
+#' Like in \code{\link{pca}}, \code{pls} uses number of components (\code{ncomp}) as a minimum of 
+#' number of objects - 1, number of x variables and the default or provided value. Regression 
+#' coefficients, predictions and other results are calculated for each set of components from 1
+#' to \code{ncomp}: 1, 1:2, 1:3, etc. The optimal number of components, (\code{ncomp.selected}), 
+#' is found using Wold's R criterion, but can be adjusted by user using function
+#' (\code{\link{selectCompNum.pls}}). The selected optimal number of components is used for all 
+#' default operations - predictions, plots, etc. 
+#'
+#' Selectivity ratio [2] and VIP scores [3] are calculated for any PLS model authomatically, however
+#' while selectivity ratio values are calculated for all computed components, the VIP scores are 
+#' computed only for selected components (to save calculation time) and recalculated every time when 
+#' \code{selectCompNum()} is called for the model. 
+#' 
+#' Calculation of confidence intervals and p-values for regression coefficients are available
+#' only by jack-knifing so far. See help for \code{\link{regcoeffs}} objects for details. 
+#'
+#' @references     
+#' 1. S. de Jong, Chemometrics and Intelligent Laboratory Systems 18 (1993) 251-263.
+#' 2. Tarja Rajalahti et al. Chemometrics and Laboratory Systems, 95 (2009), 35-48.
+#' 3. Il-Gyo Chong, Chi-Hyuck Jun. Chemometrics and Laboratory Systems, 78 (2005), 103-112.
+#'
+#' @seealso    
+#' Methods for \code{pls} objects:
+#' \tabular{ll}{
+#'  \code{print} \tab prints information about a \code{pls} object.\cr
+#'  \code{\link{summary.pls}} \tab shows performance statistics for the model.\cr
+#'  \code{\link{plot.pls}} \tab shows plot overview of the model.\cr
+#'  \code{\link{pls.simpls}} \tab implementation of SIMPLS algorithm.\cr
+#'  \code{\link{predict.pls}} \tab applies PLS model to a new data.\cr
+#'  \code{\link{selectCompNum.pls}} \tab set number of optimal components in the model.\cr
+#'  \code{\link{plotPredictions.pls}} \tab shows predicted vs. measured plot.\cr
+#'  \code{\link{plotRegcoeffs.pls}} \tab shows regression coefficients plot.\cr      
+#'  \code{\link{plotXScores.pls}} \tab shows scores plot for x decomposition.\cr
+#'  \code{\link{plotXYScores.pls}} \tab shows scores plot for x and y decomposition.\cr
+#'  \code{\link{plotXLoadings.pls}} \tab shows loadings plot for x decomposition.\cr
+#'  \code{\link{plotXYLoadings.pls}} \tab shows loadings plot for x and y decomposition.\cr
+#'  \code{\link{plotRMSE.pls}} \tab shows RMSE plot.\cr
+#'  \code{\link{plotXVariance.pls}} \tab shows explained variance plot for x decomposition.\cr
+#'  \code{\link{plotYVariance.pls}} \tab shows explained variance plot for y decomposition.\cr
+#'  \code{\link{plotXCumVariance.pls}} \tab shows cumulative explained variance plot for y 
+#'  decomposition.\cr
+#'  \code{\link{plotYCumVariance.pls}} \tab shows cumulative explained variance plot for y 
+#'  decomposition.\cr
+#'  \code{\link{plotXResiduals.pls}} \tab shows T2 vs. Q plot for x decomposition.\cr
+#'  \code{\link{plotYResiduals.pls}} \tab shows residuals plot for y values.\cr
+#'  \code{\link{plotSelectivityRatio.pls}} \tab shows plot with selectivity ratio values.\cr
+#'  \code{\link{plotVIPScores.pls}} \tab shows plot with VIP scores values.\cr
+#'  \code{\link{getSelectivityRatio.pls}} \tab returns vector with selectivity ratio values.\cr
+#'  \code{\link{getVIPScores.pls}} \tab returns vector with VIP scores values.\cr
+#'  \code{\link{getRegcoeffs.pls}} \tab returns matrix with regression coefficients.\cr
+#' }
+#'      
+#' Most of the methods for plotting data (except loadings and regression coefficients) are also 
+#' available for PLS results 
+#' (\code{\link{plsres}}) objects. There is also a randomization test for PLS-regression 
+#' (\code{\link{randtest}}).   
+#'
+#' @author 
+#' Sergey Kucheryavskiy (svkucheryavski@@gmail.com)
+#'
+#' @examples
+#' ### Examples of using PLS model class
+#' library(mdatools)   
+#'   
+#' ## 1. Make a PLS model for concentration of first component 
+#' ## using full-cross validation and automatic detection of 
+#' ## optimal number of components and show an overview
+#' 
+#' data(simdata)
+#' x = simdata$spectra.c
+#' y = simdata$conc.c[, 1]
+#' 
+#' model = pls(x, y, ncomp = 8, cv = 1)
+#' summary(model)
+#' plot(model)
+#' 
+#' ## 2. Make a PLS model for concentration of first component 
+#' ## using test set and 10 segment cross-validation and show overview
+#' 
+#' data(simdata)
+#' x = simdata$spectra.c
+#' y = simdata$conc.c[, 1]
+#' x.t = simdata$spectra.t
+#' y.t = simdata$conc.t[, 1]
+#' 
+#' model = pls(x, y, ncomp = 8, cv = 10, x.test = x.t, y.test = y.t)
+#' model = selectCompNum(model, 2)
+#' summary(model)
+#' plot(model)
+#' 
+#' ## 3. Make a PLS model for concentration of first component 
+#' ## using only test set validation and show overview
+#' 
+#' data(simdata)
+#' x = simdata$spectra.c
+#' y = simdata$conc.c[, 1]
+#' x.t = simdata$spectra.t
+#' y.t = simdata$conc.t[, 1]
+#' 
+#' model = pls(x, y, ncomp = 6, x.test = x.t, y.test = y.t)
+#' model = selectCompNum(model, 2)
+#' summary(model)
+#' plot(model)
+#' 
+#' ## 4. Show variance and error plots for a PLS model
+#' par(mfrow = c(2, 2))
+#' plotXCumVariance(model, type = 'h')
+#' plotYCumVariance(model, type = 'b', show.labels = TRUE, legend.position = 'bottomright')
+#' plotRMSE(model)
+#' plotRMSE(model, type = 'h', show.labels = TRUE)
+#' par(mfrow = c(1, 1))
+#' 
+#' ## 5. Show scores plots for a PLS model
+#' par(mfrow = c(2, 2))
+#' plotXScores(model)
+#' plotXScores(model, comp = c(1, 3), show.labels = TRUE)
+#' plotXYScores(model)
+#' plotXYScores(model, comp = 2, show.labels = TRUE)
+#' par(mfrow = c(1, 1))
+#' 
+#' ## 6. Show loadings and coefficients plots for a PLS model
+#' par(mfrow = c(2, 2))
+#' plotXLoadings(model)
+#' plotXLoadings(model, comp = c(1, 2), type = 'l')
+#' plotXYLoadings(model, comp = c(1, 2), legend.position = 'topleft')
+#' plotRegcoeffs(model)
+#' par(mfrow = c(1, 1))
+#' 
+#' ## 7. Show predictions and residuals plots for a PLS model
+#' par(mfrow = c(2, 2))
+#' plotXResiduals(model, show.label = TRUE)
+#' plotYResiduals(model, show.label = TRUE)
+#' plotPredictions(model)
+#' plotPredictions(model, ncomp = 4, xlab = 'C, reference', ylab = 'C, predictions')
+#' par(mfrow = c(1, 1))
+#' 
+#' ## 8. Selectivity ratio and VIP scores plots
+#' par(mfrow = c(2, 2))
+#' plotSelectivityRatio(model)
+#' plotSelectivityRatio(model, ncomp = 1)
+#' par(mfrow = c(1, 1))
+#' 
+#' ## 9. Variable selection with selectivity ratio
+#' selratio = getSelectivityRatio(model)
+#' selvar = !(selratio < 8)
+#' 
+#' xsel = x[, selvar]
+#' modelsel = pls(xsel, y, ncomp = 6, cv = 1)
+#' modelsel = selectCompNum(modelsel, 3)
+#' 
+#' summary(model)
+#' summary(modelsel)
+#' 
+#' ## 10. Calculate average spectrum and show the selected variables
+#' i = 1:ncol(x)
+#' ms = apply(x, 2, mean)
+#' 
+#' par(mfrow = c(2, 2))
+#' 
+#' plot(i, ms, type = 'p', pch = 16, col = 'red', main = 'Original variables')
+#' plotPredictions(model)
+#' 
+#' plot(i, ms, type = 'p', pch = 16, col = 'lightgray', main = 'Selected variables')
+#' points(i[selvar], ms[selvar], col = 'red', pch = 16)
+#' plotPredictions(modelsel)
+#' 
+#' par(mfrow = c(1, 1))
+#' 
+#' @export   
 pls = function(x, y, ncomp = 15, center = T, scale = F, cv = NULL, 
                x.test = NULL, y.test = NULL, method = 'simpls', alpha = 0.05, 
-               coeffs.ci = NULL, coeffs.alpha = 0.1, info = '')
+               coeffs.ci = NULL, coeffs.alpha = 0.1, info = '', light = F, 
+               ncomp.selcrit = 'min')
 {
-   # Calibrate and validate a PLS model.
-   #
-   # Arguments:
-   #   x: a matrix with predictor values    
-   #   y: a vector with response values
-   #   ncomp: maximum number of components to calculate
-   #   center: logical, center or not x and y data
-   #   scale: logical, standardize or not x data
-   #   cv: cross-validation settings (see \code{?crossval} for details)
-   #   x.test: a matrix with predictor values for test set validation
-   #   y.test: a vector with response values for test set validation
-   #   method: a method to calculate PLS model
-   #   alpha: a sigificance limit for Q2 values
-   #   info: a short string with information about the model
-   #
-   # Returns:
-   #   model: a PLS model (object of class pls) 
-
    x = as.matrix(x)
    y = as.matrix(y)
    
@@ -37,9 +245,22 @@ pls = function(x, y, ncomp = 15, center = T, scale = F, cv = NULL,
       {   
          cv = 1      
       }   
-      else if (cv < 10)
+      else
       {
-         warning('Number of segments in cross-validation is too small for jack-knifing!')   
+         if (is.list(cv))
+         {   
+            if (length(cv) == 1 && cv[[1]] == 'loo')
+               cvnseg = nrow(y)
+            else   
+               cvnseg = cv[[2]]
+         }   
+         else
+         {
+            cvnseg = cv
+         }   
+         
+         if (cvnseg > 1 && cvnseg < 10)
+            warning('Number of segments in cross-validation is too small for jack-knifing!')   
       }   
    }   
    
@@ -66,13 +287,13 @@ pls = function(x, y, ncomp = 15, center = T, scale = F, cv = NULL,
    # build a model and apply to calibration set
    model = pls.cal(x, y, ncomp, center = center, scale = scale, method = method)
    model$alpha = alpha   
+   model$light = light
    model$calres = predict.pls(model, x, y)
-   model = selectCompNum.pls(model, model$ncomp)
+   
    # do cross-validation if needed
    if (!is.null(cv))
    {   
-      res = pls.crossval(model, x, y, cv, center = center, scale = scale, 
-                                 jack.knife = T)    
+      res = pls.crossval(model, x, y, cv, center = center, scale = scale, jack.knife = jack.knife)    
       if (jack.knife == T)
       {   
          model$coeffs = regcoeffs(model$coeffs$values, res$jkcoeffs, coeffs.alpha)
@@ -103,6 +324,10 @@ pls = function(x, y, ncomp = 15, center = T, scale = F, cv = NULL,
       model$testres = predict.pls(model, x.test, y.test)
    }
    
+   # select optimal number of components   
+   model$ncomp.selcrit = ncomp.selcrit
+   model = selectCompNum.pls(model)
+   
    model$call = match.call()
    model$info = info
    
@@ -130,11 +355,13 @@ pls = function(x, y, ncomp = 15, center = T, scale = F, cv = NULL,
 #' algorithm for compiting PC space (only 'simpls' is supported so far)
 #' @param cv
 #' logical, does calibration for cross-validation or not
+#' @param light 
+#' logical, calculate a "light" model or normal one
 #' 
 #' @return model
 #' an object with calibrated PLS model
 #' 
-pls.cal = function(x, y, ncomp, center, scale, method = 'simpls', cv = FALSE)
+pls.cal = function(x, y, ncomp, center, scale, method = 'simpls', cv = FALSE, light = FALSE)
 {   
    # center and scale data according to arguments
    x = prep.autoscale(as.matrix(x), center = center, scale = scale)
@@ -162,7 +389,7 @@ pls.cal = function(x, y, ncomp, center, scale, method = 'simpls', cv = FALSE)
       ncomp = res$ncomp
    )
    
-   if (cv == FALSE)
+   if (!cv && !light)
    {   
       model$selratio = pls.calculateSelectivityRatio(model, x)
    }
@@ -282,7 +509,9 @@ pls.simpls = function(x, y, ncomp, cv = FALSE)
       yloadings = Q,
       yscores = U,
       ncomp = n
-   )   
+   )  
+   
+   res
 }  
 
 #' Cross-validation of a PLS model
@@ -325,9 +554,9 @@ pls.crossval = function(model, x, y, cv, center = T, scale = F, jack.knife = T)
    nrep = dim(idx)[3]
 
    yp = array(0, dim = c(nobj, ncomp, nresp))
-   Q2x = matrix(0, ncol = ncomp, nrow = nobj)   
+   Qx = matrix(0, ncol = ncomp, nrow = nobj)   
    T2x = matrix(0, ncol = ncomp, nrow = nobj)   
-   Q2y = matrix(0, ncol = ncomp, nrow = nobj)   
+   Qy = matrix(0, ncol = ncomp, nrow = nobj)   
    T2y = matrix(0, ncol = ncomp, nrow = nobj)   
    jkcoeffs = array(0, dim = c(nvar, ncomp, ncol(y), nrow(idx)))
    
@@ -356,9 +585,9 @@ pls.crossval = function(model, x, y, cv, center = T, scale = F, jack.knife = T)
             dim(m$coeffs$values) = c(dim(m$coeffs$values), 1)
             
             yp[ind, , ] = yp[ind, , , drop = F]  + res$yp
-            Q2x[ind, ]  = Q2x[ind, , drop = F] + xdist$Q2        
+            Qx[ind, ]  = Qx[ind, , drop = F] + xdist$Q        
             T2x[ind, ]  = T2x[ind, , drop = F] + xdist$T2        
-            Q2y[ind, ]  = ydist$Q2 + Q2y[ind, , drop = F]       
+            Qy[ind, ]  = ydist$Q + Qy[ind, , drop = F]       
             T2y[ind, ]  = ydist$T2 + T2y[ind, , drop = F]        
             jkcoeffs[, , , iSeg] = jkcoeffs[, , , iSeg, drop = F] + m$coeffs$values
          }   
@@ -367,9 +596,9 @@ pls.crossval = function(model, x, y, cv, center = T, scale = F, jack.knife = T)
    
    # average results over repetitions
    yp = yp / nrep
-   Q2x = Q2x / nrep
+   Qx = Qx / nrep
    T2x = T2x / nrep
-   Q2y = Q2y / nrep
+   Qy = Qy / nrep
    T2y = T2y / nrep
    jkcoeffs = jkcoeffs / nrep
    
@@ -379,11 +608,11 @@ pls.crossval = function(model, x, y, cv, center = T, scale = F, jack.knife = T)
                 xdecomp = ldecomp(totvar = model$calres$xdecomp$totvar,
                                   tnorm = model$calres$xdecomp$tnorm,
                                   ncomp.selected = model$ncomp.selected,
-                                  Q2 = Q2x, T2 = T2x),
+                                  Q = Qx, T2 = T2x),
                 ydecomp = ldecomp(totvar = model$calres$ydecomp$totvar,
                                   tnorm = model$calres$ydecomp$tnorm,
                                   ncomp.selected = model$ncomp.selected,
-                                  Q2 = Q2y, T2 = T2y)                   
+                                  Q = Qy, T2 = T2y)                   
                 )
    
    if (jack.knife == T)
@@ -406,23 +635,79 @@ pls.crossval = function(model, x, y, cv, center = T, scale = F, jack.knife = T)
 #' the same model with selected number of components
 #'
 #' @details
+#' If number of components is not specified, the Wold's R criterion is used.
 #' See examples in help for \code{\link{pls}} function.
 #' 
-selectCompNum.pls = function(model, ncomp)
+#' @export
+selectCompNum.pls = function(model, ncomp = NULL)
 {
-   if (ncomp > model$ncomp || ncomp < 0)
-      stop('Wrong number of selected components!')
-   
+   if (!is.null(ncomp))
+   {
+      # user defined number of components
+      if (ncomp > model$ncomp || ncomp < 0)
+         stop('Wrong number of selected components!')
+   }
+   else
+   {
+      # automatic estimation of the optimal number of components
+      n = dim(model$coeffs$values)[3]
+      
+      if (!is.null(model$cvres))
+         press = (model$cvres$rmse * n)^2
+      else if (!is.null(model$testres))
+         press = (model$testres$rmse * n)^2
+      else
+      {   
+         press = (model$calres$rmse * n)^2
+         warning('No validation results were found!')
+      }
+      
+      if (model$ncomp.selcrit == 'wold')
+      {   
+         # using Wold's criterion
+         ncomp = ncol(press)
+         if (ncomp > 2)
+         {
+            r = press[, 2:ncomp] / press[, 1:(ncomp - 1)] 
+            ind = which(r > 0.95, arr.ind = TRUE)
+            if (length(ind) == 0)
+               ncomp = 1
+            else if (is.null(dim(ind)))
+               ncomp = min(ind)
+            else
+               ncomp = min(ind[, 2])
+         }
+         else
+         {
+            ncomp = which.min(press)
+         }   
+      } 
+      else if (model$ncomp.selcrit == 'min')   
+      {
+         # using first local minimum
+         df = diff(as.vector(press)) > 0
+         if (any(df))
+            ncomp = which(df)[1]
+         else
+            ncomp = length(press)
+      }
+      else
+      {
+         stop('Wrong value for "ncomp.selcrit" argument!')
+      }   
+   }   
+      
    model$ncomp.selected = ncomp      
    model$calres$ncomp.selected = ncomp
-   
+
    if (!is.null(model$cvres)) 
       model$cvres$ncomp.selected = ncomp
    
    if (!is.null(model$testres)) 
       model$testres$ncomp.selected = ncomp
 
-   model$vipscores = pls.calculateVIPScores(model)
+   if (!model$light)
+      model$vipscores = pls.calculateVIPScores(model)
    
    model
 }   
@@ -449,6 +734,7 @@ selectCompNum.pls = function(model, ncomp)
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #'  
+#' @export
 predict.pls = function(object, x, y.ref = NULL, cv = F, ...)
 {   
    nresp = dim(object$coeffs$values)[3]
@@ -510,7 +796,7 @@ predict.pls = function(object, x, y.ref = NULL, cv = F, ...)
          ydist = ldecomp.getDistances(xscores, object$yloadings, yresiduals)
          ydecomp = ldecomp(yscores, object$yloadings, yresiduals, sum(yy^2),
                            object$ytnorm, object$ncomp.selected,
-                           ydist$T2, ydist$Q2)
+                           ydist$T2, ydist$Q)
       }
       else
       {
@@ -666,6 +952,7 @@ pls.calculateVIPScores = function(object)
 #' @return
 #' vector with selectivity ratio values
 #' 
+#' @export
 getSelectivityRatio.pls = function(obj, ncomp = NULL, ny = 1, ...)
 {
    if (is.null(ncomp))
@@ -699,11 +986,82 @@ getSelectivityRatio.pls = function(obj, ncomp = NULL, ny = 1, ...)
 #' @return
 #' vector with VIP scores values
 #' 
+#' @export
 getVIPScores.pls = function(obj, ny = 1, ...)
 {
    vipscores = obj$vipscores[, ny, drop = F]
 }
 
+
+#' Regression coefficients for PLS model'
+#'
+#' @description 
+#' Returns a matrix with regression coefficients for
+#' the PLS model which can be applied to a data directly
+#' 
+#' @param obj
+#' a PLS model (object of class \code{pls})
+#' @param ncomp
+#' number of components to return the coefficients for
+#' @param ...
+#' other parameters
+#'
+#' @details 
+#' The method recalculates the regression coefficients found by the PLS algorithm
+#' taking into account centering and scaling of predictors and responses, so the 
+#' matrix with coefficients can be applied directly to original data (yp = Xb).
+#' 
+#' If number of components is not specified, the optimal number, selected by user
+#' or identified by a model will be used.
+#'  
+#' @return 
+#' A matrix (n of predictors x n of responses) with regression coefficients.
+#'  
+#' @export
+getRegcoeffs.pls = function(obj, ncomp = NULL, ...)
+{
+   if (is.null(ncomp)) 
+      ncomp = obj$ncomp.selected
+   else if (ncomp <= 0 || ncomp > obj$ncomp) 
+      stop('Wrong value for number of components!')
+   
+   coeffs = obj$coeffs$values[, ncomp, , drop = F]
+   coeffs = matrix(coeffs, nrow = dim(coeffs)[1], ncol = dim(coeffs)[3])
+   xscale = obj$xscale
+   if (is.logical(xscale))
+      xscale = matrix(1, nrow = nrow(coeffs))
+  
+   xcenter = obj$xcenter 
+   if (is.logical(xcenter))
+      xcenter = matrix(0, nrow = nrow(coeffs))
+      
+   yscale = obj$yscale
+   if (is.logical(yscale))
+      yscale = matrix(1, nrow = ncol(coeffs))
+  
+   ycenter = obj$ycenter 
+   if (is.logical(ycenter))
+      ycenter = matrix(0, nrow = ncol(coeffs))
+      
+   # calculate intercept
+   b0 = sweep(coeffs,  1, xcenter, '*')
+   b0 = sweep(b0, 1, xscale, '/')
+   b0 = apply(-b0, 2, sum)
+   b0 = matrix(b0, nrow = 1)
+   b0 = sweep(b0, 2, yscale, '*')
+   b0 = sweep(b0, 2, ycenter, '+')
+   
+   # rescale coefficients
+   coeffs = sweep(coeffs, 1, xscale, '/');
+   coeffs = sweep(coeffs, 2, yscale, '*');
+   coeffs = rbind(b0, coeffs)
+   
+   rownames(coeffs) = c('Intercept', dimnames(obj$coeffs$values)[[1]])
+   colnames(coeffs) = dimnames(obj$coeffs$values)[[3]]
+   
+   coeffs
+}   
+
 #' VIP scores plot for PLS model
 #' 
 #' @description
@@ -728,6 +1086,7 @@ getVIPScores.pls = function(obj, ny = 1, ...)
 #' @references
 #' [1] Il-Gyo Chong, Chi-Hyuck Jun. Chemometrics and Laboratory Systems, 78 (2005), pp. 103-112.
 #' 
+#' @export
 plotVIPScores.pls = function(obj, ny = 1, type = 'l', main = NULL, 
                              xlab = 'Variables', ylab = '', ...)
 {   
@@ -764,6 +1123,7 @@ plotVIPScores.pls = function(obj, ny = 1, type = 'l', main = NULL,
 #' @references
 #' [1] Tarja Rajalahti et al. Chemometrics and Laboratory Systems, 95 (2009), pp. 35-48.
 #' 
+#' @export
 plotSelectivityRatio.pls = function(obj, ncomp = NULL, ny = 1, type = 'l', main = NULL, 
                                     xlab = 'Variables', ylab = '', ...)
 {
@@ -803,6 +1163,7 @@ plotSelectivityRatio.pls = function(obj, ncomp = NULL, ny = 1, type = 'l', main
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotRMSE.pls = function(obj, ny = 1, type = 'b',
                         main = 'RMSE', xlab = 'Components', ylab = NULL, 
                         show.legend = T, show.labels = F, ...)
@@ -870,6 +1231,7 @@ plotRMSE.pls = function(obj, ny = 1, type = 'b',
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotXVariance.pls = function(obj, type = 'b',
                              main = 'X variance', xlab = 'Components', 
                              ylab = 'Explained variance, %', 
@@ -902,6 +1264,7 @@ plotXVariance.pls = function(obj, type = 'b',
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotYVariance.pls = function(obj, type = 'b',
                              main = 'Y variance', xlab = 'Components', 
                              ylab = 'Explained variance, %', 
@@ -934,6 +1297,7 @@ plotYVariance.pls = function(obj, type = 'b',
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotXCumVariance.pls = function(obj, type = 'b',
                                 main = 'X cumulative variance', 
                                 xlab = 'Components', ylab = 'Explained variance, %', 
@@ -967,6 +1331,7 @@ plotXCumVariance.pls = function(obj, type = 'b',
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotYCumVariance.pls = function(obj, type = 'b',
                                 main = 'Y cumulative variance', 
                                 xlab = 'Components', ylab = 'Explained variance, %', 
@@ -1006,6 +1371,7 @@ plotYCumVariance.pls = function(obj, type = 'b',
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotVariance.pls = function(obj, decomp = 'xdecomp', variance = 'expvar',
                             type = 'b',
                             main = 'X variance', xlab = 'Components', 
@@ -1070,6 +1436,7 @@ plotVariance.pls = function(obj, decomp = 'xdecomp', variance = 'expvar',
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotXScores.pls = function(obj, comp = c(1, 2), main = 'X scores',
                            xlab = NULL, ylab = NULL,
                            show.axes = T, 
@@ -1169,6 +1536,7 @@ plotXScores.pls = function(obj, comp = c(1, 2), main = 'X scores',
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #'
+#' @export
 plotXYScores.pls = function(obj, comp = 1, main = NULL,
                             xlab = 'X scores', ylab = 'Y scores',
                             show.axes = T,
@@ -1242,7 +1610,8 @@ plotXYScores.pls = function(obj, comp = 1, main = NULL,
 #'
 #' @details
 #' See examples in help for \code{\link{pls}} function.
-#' 
+#'
+#' @export
 plotPredictions.pls = function(obj, ncomp = NULL, ny = 1, main = NULL, xlab = NULL,
                                ylab = NULL, legend.position = 'topleft', show.line = T, show.labels = F,
                                show.legend = T, colmap = 'default', col = NULL, ...)
@@ -1345,6 +1714,7 @@ plotPredictions.pls = function(obj, ncomp = NULL, ny = 1, main = NULL, xlab = NU
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotYResiduals.pls = function(obj, ncomp = NULL, ny = 1, type = 'p', 
                               main = NULL, 
                               ylab = NULL,
@@ -1469,13 +1839,16 @@ plotYResiduals.pls = function(obj, ncomp = NULL, ny = 1, type = 'p',
 #' main plot title
 #' @param ylab
 #' label for y axis
+#' @param show.ci
+#' logical, show or not confidence intervals if they are available
 #' @param ...
 #' other plot parameters (see \code{mdaplotg} for details)
 #'
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
-plotRegcoeffs.pls = function(obj, ncomp = NULL, ny = 1, main = NULL, ylab = NULL, ...)
+#' @export
+plotRegcoeffs.pls = function(obj, ncomp = NULL, ny = 1, main = NULL, ylab = NULL, show.ci = T, ...)
 {
    if (is.null(main))
    {   
@@ -1498,7 +1871,7 @@ plotRegcoeffs.pls = function(obj, ncomp = NULL, ny = 1, main = NULL, ylab = NULL
    else if (ncomp <= 0 || ncomp > obj$ncomp) 
       stop('Wrong value for number of components!')
    
-   plot(obj$coeffs, ncomp = ncomp, ny = ny, main = main, ylab = ylab, ...)
+   plot(obj$coeffs, ncomp = ncomp, ny = ny, main = main, ylab = ylab, show.ci = show.ci, ...)
 }
 
 #' X loadings plot for PLS
@@ -1526,6 +1899,7 @@ plotRegcoeffs.pls = function(obj, ncomp = NULL, ny = 1, main = NULL, ylab = NULL
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotXLoadings.pls = function(obj, comp = c(1, 2), type = 'p', main = 'X loadings', 
                              ylab = NULL, xlab = NULL, show.axes = T, ...)
 {
@@ -1599,6 +1973,7 @@ plotXLoadings.pls = function(obj, comp = c(1, 2), type = 'p', main = 'X loadings
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotXYLoadings.pls = function(obj, comp = c(1, 2), main = 'XY loadings', 
                              ylab = NULL, xlab = NULL, show.axes = F, ...)
 {
@@ -1632,7 +2007,7 @@ plotXYLoadings.pls = function(obj, comp = c(1, 2), main = 'XY loadings',
 #' X residuals plot for PLS
 #' 
 #' @description
-#' Shows a plot with Q2 residuals vs. Hotelling T2 values for PLS decomposition of x data.
+#' Shows a plot with Q residuals vs. Hotelling T2 values for PLS decomposition of x data.
 #' 
 #' @param obj
 #' a PLS model (object of class \code{pls})
@@ -1654,8 +2029,9 @@ plotXYLoadings.pls = function(obj, comp = c(1, 2), main = 'XY loadings',
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plotXResiduals.pls = function(obj, ncomp = NULL, 
-                              main = NULL, xlab = 'T2', ylab = 'Q2',
+                              main = NULL, xlab = 'T2', ylab = 'Squared residual distance (Q)',
                               show.labels = F, show.legend = T, ...)
 {
    if (is.null(main))
@@ -1671,9 +2047,8 @@ plotXResiduals.pls = function(obj, ncomp = NULL,
    else if (ncomp <= 0 || ncomp > obj$ncomp) 
       stop('Wrong value for number of components!')
    
-   cdata = cbind(obj$calres$xdecomp$T2[, ncomp], obj$calres$xdecomp$Q2[, ncomp])
-   
-   colnames(cdata) = c('T2', 'Q2')
+   cdata = cbind(obj$calres$xdecomp$T2[, ncomp], obj$calres$xdecomp$Q[, ncomp])
+   colnames(cdata) = c('T2', 'Q')
    rownames(cdata) = rownames(obj$calres$xdecomp$scores)
    
    data = list(cdata = cdata)
@@ -1681,8 +2056,8 @@ plotXResiduals.pls = function(obj, ncomp = NULL,
    
    if (!is.null(obj$testres))
    {
-      tdata = cbind(obj$testres$xdecomp$T2[, ncomp], obj$testres$xdecomp$Q2[, ncomp])      
-      colnames(tdata) = c('T2', 'Q2')
+      tdata = cbind(obj$testres$xdecomp$T2[, ncomp], obj$testres$xdecomp$Q[, ncomp])      
+      colnames(tdata) = c('T2', 'Q')
       rownames(tdata) = rownames(obj$testres$xdecomp$scores)
       
       data$tdata = tdata
@@ -1714,6 +2089,7 @@ plotXResiduals.pls = function(obj, ncomp = NULL,
 #' @details
 #' See examples in help for \code{\link{pls}} function.
 #' 
+#' @export
 plot.pls = function(x, ncomp = NULL, ny = 1, show.legend = T, show.labels = F, ...)
 {
    obj = x
@@ -1731,9 +2107,6 @@ plot.pls = function(x, ncomp = NULL, ny = 1, show.legend = T, show.labels = F, .
 
 #' Summary method for PLS model object
 #' 
-#' @method summary pls
-#' @S3method summary pls
-#'
 #' @description
 #' Shows performance statistics for the model.
 #' 
@@ -1746,6 +2119,7 @@ plot.pls = function(x, ncomp = NULL, ny = 1, show.legend = T, show.labels = F, .
 #' @param ...
 #' other arguments
 #' 
+#' @export
 summary.pls = function(object, ncomp = NULL, ny = NULL, ...)
 {
    obj = object
@@ -1797,9 +2171,6 @@ summary.pls = function(object, ncomp = NULL, ny = NULL, ...)
 
 #' Print method for PLS model object
 #' 
-#' @method print pls
-#' @S3method print pls
-#'
 #' @description
 #' Prints information about the object structure
 #' 
@@ -1807,7 +2178,8 @@ summary.pls = function(object, ncomp = NULL, ny = NULL, ...)
 #' a PLS model (object of class \code{pls})
 #' @param ...
 #' other arguments
-#' 
+#'
+#' @export 
 print.pls = function(x, ...)
 {
    obj = x
