@@ -1,17 +1,116 @@
-## class and methods for SIMCA classification with multiple classes (SIMCA models) ##
-
+#' SIMCA multiclass classification
+#' 
+#' @description 
+#' \code{simcam} is used to combine several one-class SIMCA models for multiclass classification. 
+#'
+#' @param models
+#' list with SIMCA models (\code{simca} objects).
+#' @param info
+#' text with information about the the object.
+#' 
+#' @details 
+#' Besides the possibility for multiclass classification, SIMCAM also provides tools for
+#' investigation of relationship among individual models (classes), such as discrimination power of 
+#' variables, Cooman's plot, model distance, etc.
+#' 
+#' When create \code{simcam} object, the calibration data from all individual SIMCA models is 
+#' extracted and combined for making predictions and calculate performance of the multi-class model. 
+#' The results are stored in \code{$calres} field of the model object.
+#' 
+#' @return 
+#' Returns an object of \code{simcam} class with following fields:
+#' \item{models }{a list with provided SIMCA models.} 
+#' \item{dispower }{an array with discrimination power of variables for each pair of individual 
+#' models.} 
+#' \item{moddist }{a matrix with distance between each each pair of individual models.} 
+#' \item{classnames }{vector with names of individual classes.} 
+#' \item{nclasses }{number of classes in the object.} 
+#' \item{info }{information provided by user when create the object.} 
+#' \item{calres }{an object of class \code{\link{simcamres}} with classification results for a 
+#' calibration data.} 
+#'
+#' @seealso 
+#' Methods for \code{simca} objects:
+#' \tabular{ll}{
+#'  \code{print.simcam} \tab shows information about the object.\cr
+#'  \code{summary.simcam} \tab shows summary statistics for the models.\cr
+#'  \code{plot.simcam} \tab makes an overview of SIMCAM model with two plots.\cr
+#'  \code{\link{predict.simcam}} \tab applies SIMCAM model to a new data.\cr
+#'  \code{\link{plotModelDistance.simcam}} \tab shows plot with distance between individual 
+#'  models.\cr
+#'  \code{\link{plotDiscriminationPower.simcam}} \tab shows plot with discrimination power.\cr
+#'  \code{\link{plotModellingPower.simcam}} \tab shows plot with modelling power for individual 
+#'  model.\cr
+#'  \code{\link{plotCooman.simcam}} \tab shows Cooman's plot for calibration data.\cr
+#'  \code{\link{plotResiduals.simcam}} \tab shows plot with Q vs. T2 residuals for calibration 
+#'  data.\cr
+#' }
+#' 
+#' Methods, inherited from \code{classmodel} class:
+#' \tabular{ll}{
+#'  \code{\link{plotPredictions.classmodel}} \tab shows plot with predicted values.\cr
+#'  \code{\link{plotSensitivity.classmodel}} \tab shows sensitivity plot.\cr
+#'  \code{\link{plotSpecificity.classmodel}} \tab shows specificity plot.\cr
+#'  \code{\link{plotMisclassified.classmodel}} \tab shows misclassified ratio plot.\cr
+#' }
+#' 
+#' Since SIMCAM objects and results are calculated only for optimal number of components, there is no
+#' sense to show such plots like sensitivity or specificity vs. number of components. However they
+#' are available as for any other classification model.
+#'
+#' @examples 
+#' ## make a multiclass SIMCA model for Iris data
+#' library(mdatools)
+#' 
+#' # split data 
+#' caldata = iris[seq(1, nrow(iris), 2), 1:4]
+#' se = caldata[1:25, ]
+#' ve = caldata[26:50, ]
+#' vi = caldata[51:75, ]
+#' 
+#' testdata = iris[seq(2, nrow(iris), 2), 1:4]
+#' testdata.cref = iris[seq(2, nrow(iris), 2), 5]
+#' 
+#' # create individual models
+#' semodel = simca(se, classname = 'setosa')
+#' semodel = selectCompNum(semodel, 1)
+#' 
+#' vimodel = simca(vi, classname = 'virginica')
+#' vimodel = selectCompNum(vimodel, 1)
+#' 
+#' vemodel = simca(ve, classname = 'versicolor')
+#' vemodel = selectCompNum(vemodel, 1)
+#' 
+#' # combine models into SIMCAM objects, show statistics and plots
+#' model = simcam(list(semodel, vimodel, vemodel), info = 'Iris data')
+#' summary(model)
+#' plot(model)
+#' 
+#' # show predictions and residuals for calibration data
+#' par(mfrow = c(2, 2))
+#' plotPredictions(model)
+#' plotCooman(model, nc = c(1, 2))
+#' plotResiduals(model, nc = 1)
+#' plotResiduals(model, nc = 2)
+#' par(mfrow = c(1, 1))
+#' 
+#' # show different plots for the model
+#' par(mfrow = c(2, 2))
+#' plotModelDistance(model, nc = 1)
+#' plotDiscriminationPower(model, nc = c(1, 2))
+#' plotModellingPower(model, nc = 1)
+#' plotModellingPower(model, nc = 2)
+#' par(mfrow = c(1, 1))
+#' 
+#' # apply the SIMCAM model to test set and show statistics and plots
+#' res = predict(model, testdata, testdata.cref)
+#' summary(res)
+#' plotPredictions(res)
+#'
+#' @export     
 simcam = function(models, info = '')
 {
-   # Create a SIMCA multiple classes classification obj
-   #
-   # Arguments:
-   #   models: a list with SIMCA one-class models (simca)
-   #   info: information about the model
-   #
-   # Returns:
-   #   model: a multiple classes SIMCA model (object of simcam class)
-
-   nclasses = length(models)
+  nclasses = length(models)
    
    classnames = models[[1]]$classname
    for (i in 2:nclasses)
@@ -61,16 +160,17 @@ simcam = function(models, info = '')
 #'
 #' @details
 #' See examples in help for \code{\link{simcam}} function.
-#'  
+#' 
+#' @export
 predict.simcam = function(object, x, c.ref = NULL, cv = F, ...)
 {
    x = as.matrix(x)
    nobj = nrow(x)
 
    c.pred = array(0, dim = c(nobj, 1, object$nclasses))
-   Q2 = array(0, dim = c(nobj, object$nclasses))
+   Q = array(0, dim = c(nobj, object$nclasses))
    T2 = array(0, dim = c(nobj, object$nclasses))
-   Q2lim = array(0, dim = c(1, object$nclasses))
+   Qlim = array(0, dim = c(1, object$nclasses))
    T2lim = array(0, dim = c(1, object$nclasses))
 
    ncomp.selected = matrix(0, nrow = 1, ncol = object$nclasses)
@@ -89,15 +189,15 @@ predict.simcam = function(object, x, c.ref = NULL, cv = F, ...)
 
       ncomp.selected[i] = object$models[[i]]$ncomp.selected
       c.pred[, , i] = res$c.pred[, ncomp.selected[i], ]
-      Q2[, i] = res$Q2[, ncomp.selected[i], drop = F]
+      Q[, i] = res$Q[, ncomp.selected[i], drop = F]
       T2[, i] = res$T2[, ncomp.selected[i], drop = F]
-      Q2lim[i] = res$Q2lim[ncomp.selected[i]]
+      Qlim[i] = res$Qlim[ncomp.selected[i]]
       T2lim[i] = res$T2lim[ncomp.selected[i]]
    }
    
    dimnames(c.pred) = list(rownames(x), paste('Comp', ncomp.selected[[i]]), object$classnames)
    cres = classres(c.pred, c.ref, ncomp.selected = ncomp.selected)
-   res = simcamres(cres, T2, Q2, T2lim, Q2lim)
+   res = simcamres(cres, T2, Q, T2lim, Qlim)
    res
 }
 
@@ -217,6 +317,8 @@ simcam.getPerformanceStatistics = function(model)
       dispower = dispower,
       moddist = moddist
       )
+   
+   stat
 }
 
 #' Modelling distance plot for SIMCAM model
@@ -244,6 +346,7 @@ simcam.getPerformanceStatistics = function(model)
 #' @details
 #' See examples in help for \code{\link{simcam}} function.
 #' 
+#' @export
 plotModelDistance.simcam = function(obj, nc = 1, type = 'h', main = NULL, xlab = 'Models', ylab = '', 
                                     xticklabels = NULL, ...)
 {
@@ -280,6 +383,7 @@ plotModelDistance.simcam = function(obj, nc = 1, type = 'h', main = NULL, xlab =
 #' @details
 #' See examples in help for \code{\link{simcam}} function.
 #' 
+#' @export
 plotDiscriminationPower.simcam = function(obj, nc = c(1, 2), type = 'h', main = NULL, 
                                           xlab = 'Variables', ylab = '', ...)
 {
@@ -319,6 +423,7 @@ plotDiscriminationPower.simcam = function(obj, nc = c(1, 2), type = 'h', main =
 #' @details
 #' See examples in help for \code{\link{simcam}} function.
 #' 
+#' @export
 plotCooman.simcam = function(obj, nc = c(1, 2), ...)
 {
    plotCooman(obj$calres, nc = nc, ...)
@@ -337,6 +442,7 @@ plotCooman.simcam = function(obj, nc = c(1, 2), ...)
 #' @details
 #' See examples in help for \code{\link{simcam}} function.
 #' 
+#' @export
 plotResiduals.simcam = function(obj, ...)
 {
    plotResiduals(obj$calres, ...)
@@ -359,6 +465,7 @@ plotResiduals.simcam = function(obj, ...)
 #' @details
 #' See examples in help for \code{\link{simcam}} function.
 #' 
+#' @export
 plotModellingPower.simcam = function(obj, nc = 1, main = NULL, ...)
 {
    if (is.null(main))
@@ -382,6 +489,7 @@ plotModellingPower.simcam = function(obj, nc = 1, main = NULL, ...)
 #' @details
 #' See examples in help for \code{\link{simcam}} function.
 #' 
+#' @export
 plot.simcam = function(x, nc = c(1, 2), ...)
 {
    obj = x
@@ -394,9 +502,6 @@ plot.simcam = function(x, nc = c(1, 2), ...)
 
 #' Summary method for SIMCAM model object
 #' 
-#' @method summary simcam
-#' @S3method summary simcam
-#'
 #' @description
 #' Shows performance statistics for the model.
 #' 
@@ -405,6 +510,7 @@ plot.simcam = function(x, nc = c(1, 2), ...)
 #' @param ...
 #' other arguments
 #' 
+#' @export
 summary.simcam = function(object, ...)
 {
    obj = object
@@ -421,9 +527,6 @@ summary.simcam = function(object, ...)
 
 #' Print method for SIMCAM model object
 #' 
-#' @method print simcam
-#' @S3method print simcam
-#'
 #' @description
 #' Prints information about the object structure
 #' 
@@ -431,7 +534,8 @@ summary.simcam = function(object, ...)
 #' a SIMCAM model (object of class \code{simcam})
 #' @param ...
 #' other arguments
-#' 
+#'
+#' @export 
 print.simcam = function(x, ...)
 {
    obj = x
